DREsplit - splitting schemes for differential Riccati equations
===============================================================
Copyright 2018 Tony Stillfjord

DREsplit is licensed under GPLv3 or later, see the file COPYING for details.

Contact: tony.stillfjord@gmail.com


## Description
This package contains code for approximating the solutions to matrix
differential Riccati equations (DREs). It is still under active 
development, and no guarantees are provided as to correctness, 
completeness or backwards compatibility. See the bottom of this file 
for references describing the implemented algorithms.

## Installation
To install, simply download or clone the project and add the resulting 
folder to MATLAB's path.

## Example usage
The file example.m demonstrates how to provide the code with the parameters
of a DRE (e.g. matrices A, B, C, etc.) and approximate its solution.

The file example_error_framework.m additionally demonstrates how to use the
accompanying code for comparing different solvers. This considers the same 
problem for different time steps and different solvers and may compute
different kinds of errors. It also keeps track of the computation times, 
allowing for efficiency plots. <Not yet updated to new syntax.>

The file example_nonautonomous.m demonstrates how to solve a non-autonomous
problem, i.e. one where the matrices may depend on time. This is more
expensive than the autonomous case.

## Available solvers
Currently the following solvers are available:

* Lie splitting (1st-order) ['Lie']
* Strang splitting (2nd-order) ['Strang']
* Asymmetric additive splitting of orders >=2['Asymmetric']
* Symmetric additive splitting of orders 2, 4, 6, ... ['Symmetric']
* Adaptive symmetric additive splitting of orders 2, 4, 6 and 8

For the first four types, run general_solver(args) with args.solver being 
the keyword in brackets. The (a)symmetric solvers also need args.order to 
be specified. The asymmetric schemes allow any positive integer order, 
while the symmetric schemes have even orders.

The adaptive time stepping scheme has not yet been adapted to the new 
syntax but may be run separately using the function 
additive_symmetric_adaptive.m .

## Note on parallelization:
The code uses parfor statements in some critical loops, mostly useful in 
the additive schemes. For small problems, the extra overhead of this 
parallelization may dominate the computation cost. To avoid this, make 
sure that MATLAB does not start a parallel pool automatically, and set 
one up manually if necessary.


## References:

Stillfjord, T., Low-rank second-order splitting of large-scale differential
Riccati equations, IEEE Trans. Automat. Control 60(10) (2015), 
pp. 2791-2796.

Stillfjord, T., Adaptive high-order splitting schemes for large-scale 
differential Riccati equations, Numer Algor (2017), https://doi.org/10.1007/s11075-017-0416-8
